Stan Math Library: stan/math/rev/mat/fun/stan_print.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

stan_print.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_MAT_FUN_STAN_PRINT_HPP
2 #define STAN_MATH_REV_MAT_FUN_STAN_PRINT_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <ostream>
6
7 namespace stan {
8 namespace math {
9
10 void stan_print(std::ostream* o, const var& x) {
11 *o << x.val();
12 }
13
14 }
15 }
16 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::stan_print
void stan_print(std::ostream *o, const T &x)
Definition: stan_print.hpp:12
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.